#!/bin/sh
#
# Descr: This simply runs the usual 'updateclient' command plus 1 or 2
#        other minor fix ups needed when starting over after an OSCAR test.
#        There are a few options related to running bootloader and running
#        the script in a "dry-run" that does no writes/deletes.
#
# Last Updated: tjn Wed Aug 25 10:24:53 EDT 2004
#---------------------------------------------------------------------------

##########################################################################
#
# Configuration Options
#
##########################################################################

server=bear.csm.ornl.gov
image=test1
#dryrun='-dry-run'
#bootloader=' --no-bootloader'

# MUST live in '/home/$oscaruser'
oscaruser='oscartst'



##########################################################################
#
# Should not need to modify below this line.
#
##########################################################################
echo " ****************************************************"
echo
echo "              Remember to start the "
echo "            (depending on SI version)"
echo "      'systemimager-server-rsyncd' service on $server"
echo "                        or"
echo "           'systemimager' service on $server"
echo
echo " ****************************************************"
echo

if [ -z $dryrun ]; then
   echo 
   echo "   Synching this system to the '$image' image "
   echo 
   /usr/sbin/updateclient $bootloader -server $server -image $image 
else 
   echo 
   echo "       *** DRY-RUN ***"
   echo "    (no writes performed)"
   echo
   echo "   Synching this system to the '$image' image "
   echo 
   /usr/sbin/updateclient $dryrun $bootloader -server $server -image $image 
fi

#
# Remove any OSCAR Test User directory that may remain
#
/bin/ls -ld /home/$oscaruser >& /dev/null
if [ $? -eq 0 ]; then
   echo 
   echo "    The '/home/$oscaruser' directory exists, removing!"
   echo
   if [ -z $dryrun ]; then
       (cd /home; rm -rf $oscaruser)
   else
       echo "       *** DRY-RUN ***"
       echo "    (no remove performed)"
       echo 
   fi
fi

#
# Remove some /var material that should be removed after OSCAR tests
#
# PBS / Torque
/bin/ls -ld /var/spool/pbs >& /dev/null
if [ $? -eq 0 ]; then
   echo 
   echo "    The '/var/spool/pbs' directory exists, removing!"
   echo
   if [ -z $dryrun ]; then
       (cd /var/spool; rm -rf pbs)
   else
       echo "       *** DRY-RUN ***"
       echo "    (no remove performed)"
       echo 
   fi
fi

# SSS
/bin/ls -ld /var/spool/sss >& /dev/null
if [ $? -eq 0 ]; then
   echo 
   echo "    The '/var/spool/sss' directory exists, removing!"
   echo
   if [ -z $dryrun ]; then
       (cd /var/spool; rm -rf sss)
   else
       echo "       *** DRY-RUN ***"
       echo "    (no remove performed)"
       echo 
   fi
fi

# Bamboo
/bin/ls -ld /var/spool/bamboo >& /dev/null
if [ $? -eq 0 ]; then
   echo 
   echo "    The '/var/spool/bamboo' directory exists, removing!"
   echo
   if [ -z $dryrun ]; then
       (cd /var/spool; rm -rf bamboo)
   else
       echo "       *** DRY-RUN ***"
       echo "    (no remove performed)"
       echo 
   fi
fi


echo "Done."
